==> generator-express-ts-1.0.2.tgz: package/generators/app/templates/basic/src/app.ts <==
'use strict';

import * as express from 'express';
import * as path from 'path';
import * as favicon from 'serve-favicon';
import * as logger from 'morgan';
import * as cookieParser from 'cookie-parser';
import * as bodyParser from 'body-parser';
import index from './routes/index';<% if(options.viewEngine == 'ejs'){ %>
import * as ejs from 'ejs';<% } %>

const app: express.Express = express();

//view engine setup
<% if(options.viewEngine == 'jade'){ %>app.set('views',path.join(__dirname,'views'));
app.set('view engine','jade');<% }else if(options.viewEngine == 'ejs'){ %>
app.set('views',path.join(__dirname,'views'));
app.engine('.html',ejs.renderFile);
app.set('view engine','html');<% } %>

//uncomment after placing your favicon in /public
//app.use(favicon(path.join(__dirname,'public','favicon.ico')));
app.use(logger('dev'));
app.use(bodyParser.json());
app.use(bodyParser.urlencoded({extended: false}));
app.use(cookieParser());
app.use(express.static(path.join(__dirname,'public')));

app.use('/',index);

//catch 404 and forward to error handler
app.use((req,res,next) => {
  var err = new Error('Not Found');
  err['status'] = 404;
  next(err);
});

//error handlers

//development error handler
//will print stacktrace
if(process.env.NODE_ENV === 'development') {
  app.use((err: Error,req,res,next) => {
    res.status(err['status'] || 500);
    res.render('error',{
      title: 'error',
      message: err.message,
      error: err
    });
  });    
}

//production error handler
// no stacktrace leaked to user
app.use((err: Error,req,res,next) => {
  res.status(err['status'] || 500);
  res.render('error',{
    title: 'error',
    message: err.message,
    error: {}
  });
});

export default app;

==> generator-express-ts-1.0.5.tgz: package/generators/app/templates/basic/src/app.ts <==
'use strict';

import * as express from 'express';
import * as path from 'path';
import * as favicon from 'serve-favicon';
import * as logger from 'morgan';
import * as cookieParser from 'cookie-parser';
import * as bodyParser from 'body-parser';
import index from './routes/index';<% if(options.viewEngine == 'ejs'){ %>
import * as ejs from 'ejs';<% } %>

const app: express.Express = express();

//view engine setup
<% if(options.viewEngine == 'pug'){ %>app.set('views',path.join(__dirname,'views'));
app.set('view engine','pug');<% }else if(options.viewEngine == 'ejs'){ %>
app.set('views',path.join(__dirname,'views'));
app.engine('.html',ejs.renderFile);
app.set('view engine','html');<% } %>

//uncomment after placing your favicon in /public
//app.use(favicon(path.join(__dirname,'public','favicon.ico')));
app.use(logger('dev'));
app.use(bodyParser.json());
app.use(bodyParser.urlencoded({extended: false}));
app.use(cookieParser());
app.use(express.static(path.join(__dirname,'public')));

app.use('/',index);

//catch 404 and forward to error handler
app.use((req,res,next) => {
  var err = new Error('Not Found');
  err['status'] = 404;
  next(err);
});

//error handlers

//development error handler
//will print stacktrace
if(process.env.NODE_ENV === 'development') {
  app.use((err: Error,req,res,next) => {
    res.status(err['status'] || 500);
    res.render('error',{
      title: 'error',
      message: err.message,
      error: err
    });
  });    
}

//production error handler
// no stacktrace leaked to user
app.use((err: Error,req,res,next) => {
  res.status(err['status'] || 500);
  res.render('error',{
    title: 'error',
    message: err.message,
    error: {}
  });
});

export default app;
